stl
===

Homicides and selected socio-economic characteristics for counties surrounding St Louis, MO. Data aggregated for three time periods: 1979-84 (steady decline in homicides), 1984-88 (stable period), and 1988-93 (steady increase in homicides).
---------------------------------------------------------------------------

* stl.gal: queen contiguity weights in GAL format.
* stl_hom.csv: attribute data and WKT geometry.
* stl_hom.dbf: attribute data. (k=22)
* stl_hom.html: metadata.
* stl_hom.shp: Polygon shapefile. (n=78)
* stl_hom.shx: spatial index.
* stl_hom.txt: selected attribute data.
* stl_hom.wkt: a Well-Known-Text representation of the geometry.
* stl_hom_rook.gal: rook contiguity weights in GAL format.

Source: S. Messner, L. Anselin, D. Hawkins, G. Deane, S. Tolnay, R. Baller (2000). An Atlas of the Spatial Patterning of County-Level Homicide, 1960-1990. Pittsburgh, PA, [National Consortium on Violence Research (NCOVR)](http://www.ncovr.heinz.cmu.edu).
